..
      Copyright (c) 2019 Red Hat, Inc.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

===============================
Octavia Provider Feature Matrix
===============================

Load Balancer Features
======================

Provider feature support matrix for an Octavia load balancer.

Load Balancer API Features
--------------------------

These features are documented in the Octavia API reference
`Create a Load Balancer <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-a-load-balancer-detail#create-a-load-balancer>`_ section.

.. support_matrix:: feature-matrix-lb.ini

Listener Features
=================

Provider feature support matrix for an Octavia load balancer listener.

Listener API Features
---------------------

These features are documented in the Octavia API reference
`Create a Listener <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-listener-detail#create-listener>`_ section.

.. support_matrix:: feature-matrix-listener.ini

Pool Features
=============

Provider feature support matrix for an Octavia load balancer pool.

Pool API Features
-----------------

These features are documented in the Octavia API reference
`Create a Pool <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-pool-detail#create-pool>`_ section.

.. support_matrix:: feature-matrix-pool.ini

Member Features
===============

Provider feature support matrix for an Octavia load balancer member.

Member API Features
-------------------

These features are documented in the Octavia API reference
`Create a Member <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-member-detail#create-member>`_ section.

.. support_matrix:: feature-matrix-member.ini

Health Monitor Features
=======================

Provider feature support matrix for an Octavia load balancer health monitor.

Health Monitor API Features
---------------------------

These features are documented in the Octavia API reference
`Create a Health Monitor <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-health-monitor-detail#create-health-monitor>`_ section.

.. support_matrix:: feature-matrix-healthmonitor.ini

L7 Policy Features
==================

Provider feature support matrix for an Octavia load balancer L7 Policies.

L7 Policy API Features
----------------------

These features are documented in the Octavia API reference
`Create an L7 Policy <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-l7-policy-detail#create-an-l7-policy>`_ section.

.. support_matrix:: feature-matrix-l7policy.ini

L7 Rule Features
================

Provider feature support matrix for an Octavia load balancer L7 Rules.

L7 Rule API Features
--------------------

These features are documented in the Octavia API reference
`Create an L7 Rule <https://docs.openstack.org/api-ref/load-balancer/v2/index.html?expanded=create-l7-rule-detail#create-an-l7-rule>`_ section.

.. support_matrix:: feature-matrix-l7rule.ini
